@@ -4,7 +4,7 @@ use warnings;
 
 use CGI::Snapp;
 
-use Data::Dumper; # For Dumper().
+use Data::Dumper::Concise; # For Dumper().
 
 use Log::Handler;
 
@@ -31,8 +31,6 @@ my($app)   = CGI::Snapp -> new(logger => $logger, send_output => 0);
 
 # Get the default params, of which there are none.
 
-=pod
-
 diag 'Start test 1';
 diag '-' x 20;
 diag Dumper([$app -> param]);
@@ -40,8 +38,6 @@ diag '-' x 20;
 diag Dumper([]);
 diag '-' x 20;
 
-=cut
-
 cmp_deeply([$app -> param], [], 'No params are set by default'); $count++;
 
 # Set/get a hash of params.
@@ -52,23 +48,17 @@ $app -> param(%old_params);
 
 my(%new_params) = map{($_ => $app -> param($_) )} $app -> param;
 
-=pod
-
 diag 'Start test 2';
 diag '-' x 20;
-diag Dumper(\%old_params);
+diag Dumper([sort %old_params]);
 diag '-' x 20;
-diag Dumper(\%new_params);
+diag Dumper([sort %new_params]);
 diag '-' x 20;
 
-=cut
-
 cmp_deeply([sort %old_params], [sort %new_params], 'Can set and get a hash of params'); $count++;
 
 $app -> delete($_) for keys %old_params;
 
-=pod
-
 diag 'Start test 3';
 diag '-' x 20;
 diag Dumper([$app -> param]);
@@ -76,8 +66,6 @@ diag '-' x 20;
 diag Dumper([]);
 diag '-' x 20;
 
-=cut
-
 cmp_deeply([$app -> param], [], 'No params are set after mass delete'); $count++;
 
 # Set/get a hashref of params.
@@ -88,23 +76,17 @@ $app -> param($old_params);
 
 %new_params = map{($_ => $app -> param($_) ) } $app -> param;
 
-=pod
-
 diag 'Start test 4';
 diag '-' x 20;
-diag Dumper($old_params);
+diag Dumper([sort %$old_params]);
 diag '-' x 20;
-diag Dumper(\%new_params);
+diag Dumper([sort %new_params]);
 diag '-' x 20;
 
-=cut
-
 cmp_deeply([sort %$old_params], [sort %new_params], 'Can set and get a hash of params'); $count++;
 
 $app -> delete($_) for keys %$old_params;
 
-=pod
-
 diag 'Start test 5';
 diag '-' x 20;
 diag Dumper([$app -> param]);
@@ -112,8 +94,6 @@ diag '-' x 20;
 diag Dumper([]);
 diag '-' x 20;
 
-=cut
-
 cmp_deeply([$app -> param], [], 'No params are set after mass delete'); $count++;
 
 # Add params in stages.
@@ -130,8 +110,6 @@ $app -> param(%old_params);
 
 my($value) = $app -> param(%old_params);
 
-=pod
-
 diag 'Start test 6';
 diag '-' x 20;
 diag Dumper($value);
@@ -139,12 +117,8 @@ diag '-' x 20;
 diag Dumper(5);
 diag '-' x 20;
 
-=cut
-
 ok($value == 5, 'param($key => $value) returns that value');                $count++;
 
-=pod
-
 diag 'Start test 7';
 diag '-' x 20;
 diag Dumper($value);
@@ -152,25 +126,19 @@ diag '-' x 20;
 diag Dumper($app -> param('five') );
 diag '-' x 20;
 
-=cut
-
 ok($value == $app -> param('five'), 'param($key) also returns that value'); $count++;
 
 %old_params = (one => 1, two => 2, three => 3, four => 4, %old_params);
 
 %new_params = map{($_ => $app -> param($_) )} $app -> param;
 
-=pod
-
 diag 'Start test 8';
 diag '-' x 20;
-diag Dumper(\%old_params);
+diag Dumper([sort %old_params]);
 diag '-' x 20;
-diag Dumper(\%new_params);
+diag Dumper([sort %new_params]);
 diag '-' x 20;
 
-=cut
-
 cmp_deeply([sort %old_params], [sort %new_params], 'Params match after being added in stages'); $count++;
 
 # What is returned after delete()?
@@ -178,8 +146,6 @@ cmp_deeply([sort %old_params], [sort %new_params], 'Params match after being add
 my($key) = 'five';
 $value   = $app -> delete($key);
 
-=pod
-
 diag 'Start test 9';
 diag '-' x 20;
 diag Dumper($value);
@@ -187,36 +153,26 @@ diag '-' x 20;
 diag Dumper(5);
 diag '-' x 20;
 
-=cut
-
 ok($value == 5, "delete($key) returns the corresponding value: $value");            $count++;
 
-=pod
-
 diag 'Start test 10';
 diag '-' x 20;
 diag Dumper($app -> param($key) );
 diag '-' x 20;
-diag '$VAR1 = undef;';
+diag 'undef';
 diag '-' x 20;
 
-=cut
-
 ok(! defined $app -> param($key), "After delete($key), param($key) returns undef"); $count++;
 
 $value = $app -> delete($key);
 
-=pod
-
 diag 'Start test 11';
 diag '-' x 20;
 diag Dumper($value);
 diag '-' x 20;
-diag '$VAR1 = undef;';
+diag 'undef';
 diag '-' x 20;
 
-=cut
-
 ok(! defined $value, "After delete($key) twice, delete() returns undef"); $count++;
 
 # Clean up before testing an arrayref.
@@ -229,17 +185,13 @@ $app -> param($old_params);
 
 %new_params = map{($_ => $app -> param($_) )} $app -> param;
 
-=pod
-
 diag 'Start test 12';
 diag '-' x 20;
-diag Dumper($old_params);
+diag Dumper([sort @$old_params]);
 diag '-' x 20;
-diag Dumper([%new_params]);
+diag Dumper([sort %new_params]);
 diag '-' x 20;
 
-=cut
-
 cmp_deeply([sort @$old_params], [sort %new_params], 'Params match after being added via an arrayref'); $count++;
 
 done_testing($count);
